# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['smartmoneyconcepts']

package_data = \
{'': ['*']}

install_requires = \
['numba>=0.59.1,<0.60.0', 'numpy>=1.26.4,<2.0.0', 'pandas>=2.2.2,<3.0.0']

setup_kwargs = {
    'name': 'smartmoneyconcepts',
    'version': '0.0.23',
    'description': 'Getting indicators based on smart money concepts or ICT',
    'long_description': '<p align="center">\n  <img src="https://github.com/joshyattridge/smart-money-concepts/blob/f0c0fc28cc290cdd9dfcc6a6ac246ed1d59061be/tests/test.gif" alt="Candle Graph Showing Indicators"/>\n</p>\n\n# Smart Money Concepts (smc) BETA\n\nThe Smart Money Concepts Python Indicator is a sophisticated financial tool developed for traders and investors to gain insights into market sentiment, trends, and potential reversals. This indicator is inspired by Inner Circle Trader (ICT) concepts like Order blocks, Liquidity, Fair Value Gap, Swing Highs and Lows, Break of Structure, Change of Character, and more. Please Take a look and contribute to the project.\n\n## Installation\n\n```bash\npip install smartmoneyconcepts\n```\n\n## Usage\n\n```python\nfrom smartmoneyconcepts import smc\n```\n\nPrepare data to use with smc:\n\nsmc expects properly formated ohlc DataFrame, with column names in lowercase: ["open", "high", "low", "close"] and ["volume"] for indicators that expect ohlcv input.\n\n## Indicators\n\n### Fair Value Gap (FVG)\n\n```python\nsmc.fvg(ohlc, join_consecutive=False)\n```\n\nA fair value gap is when the previous high is lower than the next low if the current candle is bullish.\nOr when the previous low is higher than the next high if the current candle is bearish.\n\nparameters:<br>\njoin_consecutive: bool - if there are multiple FVG in a row then they will be merged into one using the highest top and the lowest bottom<br>\n\nreturns:<br>\nFVG = 1 if bullish fair value gap, -1 if bearish fair value gap<br>\nTop = the top of the fair value gap<br>\nBottom = the bottom of the fair value gap<br>\nMitigatedIndex = the index of the candle that mitigated the fair value gap<br>\n\n### Swing Highs and Lows\n\n```python\nsmc.swing_highs_lows(ohlc, swing_length = 50)\n```\n\nA swing high is when the current high is the highest high out of the swing_length amount of candles before and after.\nA swing low is when the current low is the lowest low out of the swing_length amount of candles before and after.\n\nparameters:<br>\nswing_length: int - the amount of candles to look back and forward to determine the swing high or low<br>\n\nreturns:<br>\nHighLow = 1 if swing high, -1 if swing low<br>\nLevel = the level of the swing high or low<br>\n\n### Break of Structure (BOS) & Change of Character (CHoCH)\n\n```python\nsmc.bos_choch(ohlc, swing_highs_lows, close_break = True)\n```\n\nThese are both indications of market structure changing\n\nparameters:<br>\nswing_highs_lows: DataFrame - provide the dataframe from the swing_highs_lows function<br>\nclose_break: bool - if True then the break of structure will be mitigated based on the close of the candle otherwise it will be the high/low.<br>\n\nreturns:<br>\nBOS = 1 if bullish break of structure, -1 if bearish break of structure<br>\nCHOCH = 1 if bullish change of character, -1 if bearish change of character<br>\nLevel = the level of the break of structure or change of character<br>\nBrokenIndex = the index of the candle that broke the level<br>\n\n### Order Blocks (OB)\n\n```python\nsmc.ob(ohlc, swing_highs_lows, close_mitigation = False)\n```\n\nThis method detects order blocks when there is a high amount of market orders exist on a price range.\n\nparameters:<br>\nswing_highs_lows: DataFrame - provide the dataframe from the swing_highs_lows function<br>\nclose_mitigation: bool - if True then the order block will be mitigated based on the close of the candle otherwise it will be the high/low.\n\nreturns:<br>\nOB = 1 if bullish order block, -1 if bearish order block<br>\nTop = top of the order block<br>\nBottom = bottom of the order block<br>\nOBVolume = volume + 2 last volumes amounts<br>\nPercentage = strength of order block (min(highVolume, lowVolume)/max(highVolume,lowVolume))<br>\n\n\n### Liquidity\n\n```python\nsmc.liquidity(ohlc, swing_highs_lows, range_percent = 0.01)\n```\n\nLiquidity is when there are multiply highs within a small range of each other.\nor multiply lows within a small range of each other.\n\nparameters:<br>\nswing_highs_lows: DataFrame - provide the dataframe from the swing_highs_lows function<br>\nrange_percent: float - the percentage of the range to determine liquidity<br>\n\nreturns:<br>\nLiquidity = 1 if bullish liquidity, -1 if bearish liquidity<br>\nLevel = the level of the liquidity<br>\nEnd = the index of the last liquidity level<br>\nSwept = the index of the candle that swept the liquidity<br>\n\n### Previous High And Low\n\n```python\nsmc.previous_high_low(ohlc, time_frame = "1D")\n```\n\nThis method returns the previous high and low of the given time frame.\n\nparameters:<br>\ntime_frame: str - the time frame to get the previous high and low 15m, 1H, 4H, 1D, 1W, 1M<br>\n\nreturns:<br>\nPreviousHigh = the previous high<br>\nPreviousLow = the previous low<br>\n\n### Sessions\n\n```python\nsmc.sessions(ohlc, session, start_time, end_time, time_zone = "UTC")\n```\n\nThis method returns which candles are within the session specified\n\nparameters:<br>\nsession: str - the session you want to check (Sydney, Tokyo, London, New York, Asian kill zone, London open kill zone, New York kill zone, london close kill zone, Custom)<br>\nstart_time: str - the start time of the session in the format "HH:MM" only required for custom session.<br>\nend_time: str - the end time of the session in the format "HH:MM" only required for custom session.<br>\ntime_zone: str - the time zone of the candles can be in the format "UTC+0" or "GMT+0"<br>\n\nreturns:<br>\nActive = 1 if the candle is within the session, 0 if not<br>\nHigh = the highest point of the session<br>\nLow = the lowest point of the session<br>\n\n### Retracements\n\n```python\nsmc.retracements(ohlc, swing_highs_lows)\n```\n\nThis method returns the percentage of a retracement from the swing high or low\n\nparameters:<br>\nswing_highs_lows: DataFrame - provide the dataframe from the swing_highs_lows function<br>\n\nreturns:<br>\nDirection = 1 if bullish retracement, -1 if bearish retracement<br>\nCurrentRetracement% = the current retracement percentage from the swing high or low<br>\nDeepestRetracement% = the deepest retracement percentage from the swing high or low<br>\n\n## Contributing\n\nThis project is still in BETA so please feel free to contribute to the project. By creating your own indicators or improving the existing ones. If you are stuggling to find something to do then please check out the issues tab for requested changes.\n\n1. Fork it (https://github.com/joshyattridge/smartmoneyconcepts/fork).\n2. Study how it\'s implemented.\n3. Create your feature branch (git checkout -b my-new-feature).\n4. Commit your changes (git commit -am \'Add some feature\').\n5. Push to the branch (git push origin my-new-feature).\n6. Create a new Pull Request.\n\n## Disclaimer\n\nThis project is for educational purposes only. Do not use this indicator as a sole decision maker for your trades. Always use proper risk management and do your own research before making any trades. The author of this project is not responsible for any losses you may incur.\n',
    'author': 'Joshua Attridge',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
